<!--- Remove sections that do not apply -->
<!--- Advice for the reporter: Please use this template to report bugs or feature requests only. -->

Issues should only be created for bugs, feature requests, or other topics
related to the **development** of the project. For general questions, please use
the
[Discussions](https://github.com/retigra/ZabbixCI/discussions/categories/q-a)
section.

<!--- Provide a general summary of the issue in the Title above -->

## Expected Behavior

<!--- Tell us what should happen -->

## Current Behavior

<!--- Tell us what happens instead of the expected behavior -->

## Possible Solution

<!--- Not obligatory, but suggest a fix/reason for the bug, -->

## Steps to Reproduce

<!--- Provide a link to a live example, or an unambiguous set of steps to -->
<!--- reproduce this bug. Include code to reproduce, if relevant -->

1.
2.
3.
4.

## Context (Environment)

<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

- ZabbixCI version:
- Zabbix version:
- Python version:

## Detailed Description

<!--- Provide a detailed description of the change or addition you are proposing -->

## Possible Implementation

<!--- Not obligatory, but suggest an idea for implementing addition or change -->
